@@ -1,4 +1,5 @@
-use super::{config::Config, Shard};
+use super::{config::Config, Events, Shard};
+use crate::EventTypeFlags;
 use std::{
     error::Error,
     fmt::{Display, Formatter, Result as FmtResult},
@@ -6,7 +7,7 @@ use std::{
 };
 use twilight_gateway_queue::{LocalQueue, Queue};
 use twilight_http::Client as HttpClient;
-use twilight_model::gateway::{payload::update_status::UpdateStatusInfo, Intents};
+use twilight_model::gateway::{payload::update_presence::UpdatePresencePayload, Intents};
 
 /// Large threshold configuration is invalid.
 ///
@@ -170,6 +171,7 @@ impl ShardBuilder {
         }
 
         Self(Config {
+            event_types: EventTypeFlags::default(),
             gateway_url: None,
             http_client: HttpClient::new(token.clone()),
             intents,
@@ -184,10 +186,24 @@ impl ShardBuilder {
     }
 
     /// Consume the builder, constructing a shard.
-    pub fn build(self) -> Shard {
+    pub fn build(self) -> (Shard, Events) {
         Shard::new_with_config(self.0)
     }
 
+    /// Set the event types to process.
+    ///
+    /// This is an optimization technique; all events not included in the
+    /// provided event type flags will not be deserialized by the gateway and
+    /// will be discarded. All events will still be sent if
+    /// [`EventTypeFlags::SHARD_PAYLOAD`] is enabled.
+    ///
+    /// [`EventTypeFlags::SHARD_PAYLOAD`]: crate::EventTypeFlags::SHARD_PAYLOAD
+    pub const fn event_types(mut self, event_types: EventTypeFlags) -> Self {
+        self.0.event_types = event_types;
+
+        self
+    }
+
     /// Set the URL used for connecting to Discord's gateway
     pub fn gateway_url(mut self, gateway_url: Option<String>) -> Self {
         self.0.gateway_url = gateway_url.map(String::into_boxed_str);
@@ -262,27 +278,27 @@ impl ShardBuilder {
     /// ```no_run
     /// use twilight_gateway::{Intents, Shard};
     /// use twilight_model::gateway::{
-    ///     payload::update_status::UpdateStatusInfo,
+    ///     payload::update_presence::UpdatePresencePayload,
     ///     presence::{ActivityType, MinimalActivity, Status},
     /// };
     ///
     /// # fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// let shard = Shard::builder("token", Intents::empty())
-    ///     .presence(UpdateStatusInfo::new(
-    ///         Some(vec![MinimalActivity {
+    ///     .presence(UpdatePresencePayload::new(
+    ///         vec![MinimalActivity {
     ///             kind: ActivityType::Playing,
     ///             name: "Not accepting commands".into(),
     ///             url: None,
     ///         }
-    ///         .into()]),
+    ///         .into()],
     ///         false,
     ///         None,
     ///         Status::Idle,
-    ///     ));
+    ///     )?);
     /// # Ok(()) }
     ///
     /// ```
-    pub fn presence(mut self, presence: UpdateStatusInfo) -> Self {
+    pub fn presence(mut self, presence: UpdatePresencePayload) -> Self {
         self.0.presence.replace(presence);
 
         self
