@@ -1,16 +1,16 @@
 use super::{
     super::{
         config::Config,
+        emitter::{EmitJsonErrorType, Emitter},
         json::{self, GatewayEventParsingError, GatewayEventParsingErrorType},
         stage::Stage,
         ShardStream,
     },
     compression::{self, Compression},
-    emitter::{EmitJsonErrorType, Emitter},
     session::{Session, SessionSendError, SessionSendErrorType},
     socket_forwarder::SocketForwarder,
 };
-use crate::{event::EventTypeFlags, listener::Listeners};
+use crate::event::EventTypeFlags;
 use serde::{Deserialize, Serialize};
 use std::{
     borrow::Cow,
@@ -266,7 +266,7 @@ impl ShardProcessor {
     pub async fn new(
         config: Arc<Config>,
         mut url: String,
-        listeners: Listeners<Event>,
+        emitter: Emitter,
     ) -> Result<(Self, WatchReceiver<Arc<Session>>), ConnectingError> {
         //if we got resume info we don't need to wait
         let shard_id = config.shard();
@@ -283,7 +283,6 @@ impl ShardProcessor {
         url.push_str("?v=8");
         compression::add_url_feature(&mut url);
 
-        let emitter = Emitter::new(listeners);
         emitter.event(Event::ShardConnecting(Connecting {
             gateway: url.clone(),
             shard_id: config.shard()[0],
@@ -362,8 +361,6 @@ impl ShardProcessor {
                 }
             }
         }
-
-        self.emitter.into_listeners().remove_all();
     }
 
     #[allow(clippy::too_many_lines)]
